clean_: Clean a 'tibble' or vector

clean_R Documentation

Clean a tibble or vector

Description

Cleans column and author names

Usage

clean_df(x)

clean_authors(x)

clean_colnames(x)

Arguments

x

A tibble with bibliographic information.

Value

Returns the input, but cleaner.

Examples

df <-  data.frame(
  X..title. = c(
    "EviAtlas: a tool for visualising evidence synthesis databases",
    "revtools: An R package to support article screening for evidence synthesis",
    "An automated approach to identifying search terms for systematic reviews",
    "Reproducible, flexible and high-throughput data extraction from primary literature"),
  YEAR = c("2019", "2019", "2019", "2019"),
  authors = c(
    "Haddaway et al",
    "Westgate",
    "EM Grames AND AN Stillman  & MW Tingley and CS Elphick",
    "Pick et al"))
clean_df(df)

# or use sub-functions
clean_colnames(df)
clean_authors(df)


synthesisr documentation built on March 26, 2026, 5:09 p.m.