override_duplicates: Manually override duplicates

View source: R/deduplication_functions.R

override_duplicatesR Documentation

Manually override duplicates

Description

Re-assign group numbers to text that was classified as duplicated but is unique.

Usage

override_duplicates(matches, overrides)

Arguments

matches

Numeric: a vector of group numbers for texts that indicates duplicates and unique values returned by the find_duplicates function.

overrides

Numeric: a vector of group numbers that are not true duplicates.

Value

The input matches vector with unique group numbers for members of groups that the user overrides.


synthesisr documentation built on March 26, 2026, 5:09 p.m.