review_duplicates: Manually review potential duplicates

View source: R/deduplication_functions.R

review_duplicatesR Documentation

Manually review potential duplicates

Description

Allows users to manually review articles classified as duplicates.

Usage

review_duplicates(text, matches)

Arguments

text

A character vector of the text that was used to identify potential duplicates.

matches

Numeric: a vector of group numbers for texts that indicates duplicates and unique values returned by the find_duplicates function.

Value

A data.frame of potential duplicates grouped together.


synthesisr documentation built on March 26, 2026, 5:09 p.m.