| clean_ | R Documentation |
tibble or vectorCleans column and author names
clean_df(x)
clean_authors(x)
clean_colnames(x)
x |
A |
Returns the input, but cleaner.
df <- data.frame(
X..title. = c(
"EviAtlas: a tool for visualising evidence synthesis databases",
"revtools: An R package to support article screening for evidence synthesis",
"An automated approach to identifying search terms for systematic reviews",
"Reproducible, flexible and high-throughput data extraction from primary literature"),
YEAR = c("2019", "2019", "2019", "2019"),
authors = c(
"Haddaway et al",
"Westgate",
"EM Grames AND AN Stillman & MW Tingley and CS Elphick",
"Pick et al"))
clean_df(df)
# or use sub-functions
clean_colnames(df)
clean_authors(df)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.